@@ -5,7 +5,7 @@ from datetime import datetime, timezone
 from deprecated import deprecated
 
 from trakt.core import get, post, delete
-from trakt.utils import slugify, extract_ids, timestamp
+from trakt.utils import slugify, timestamp
 
 
 __author__ = 'Jon Nappi'
@@ -171,12 +171,12 @@ def search(query, search_type='movie', year=None, slugify_query=False):
         'movie', 'show', 'episode', or 'person'
     :param year: This parameter is ignored as it is no longer a part of the
         official API. It is left here as a valid arg for backwards
-        compatability.
+        compatibility.
     :param slugify_query: A boolean indicating whether or not the provided
         query should be slugified or not prior to executing the query.
     """
     # the new get_search_results expects a list of types, so handle this
-    # conversion to maintain backwards compatability
+    # conversion to maintain backwards compatibility
     if isinstance(search_type, str):
         search_type = [search_type]
     results = get_search_results(query, search_type, slugify_query)
@@ -211,7 +211,6 @@ def get_search_results(query, search_type=None, slugify_query=False):
     # need to import Scrobblers
     results = []
     for media_item in data:
-        extract_ids(media_item)
         result = SearchResult(media_item['type'], media_item['score'])
         if media_item['type'] == 'movie':
             from trakt.movies import Movie
@@ -280,15 +279,11 @@ def search_by_id(query, id_type='imdb', media_type=None, slugify_query=False):
             query=query, source=source, media_type=media_type)
     data = yield uri
 
-    for media_item in data:
-        extract_ids(media_item)
-
     results = []
     for d in data:
         if 'episode' in d:
             from trakt.tv import TVEpisode
             show = d.pop('show')
-            extract_ids(d['episode'])
             results.append(TVEpisode(show.get('title', None),
                                      show_id=show['ids'].get('trakt'),
                                      **d.pop('episode')))
@@ -342,7 +337,6 @@ def get_watchlist(list_type=None, sort=None):
         if 'episode' in d:
             from trakt.tv import TVEpisode
             show = d.pop('show')
-            extract_ids(d['episode'])
             results.append(TVEpisode(show.get('title', None),
                                      show_id=show.get('trakt', None),
                                      **d['episode']))
