@@ -6,11 +6,12 @@ from urllib.parse import urlencode
 
 from trakt.core import Airs, Alias, Comment, Genre, delete, get
 from trakt.errors import NotFoundException
+from trakt.mixins import IdsMixin
 from trakt.sync import (Scrobbler, rate, comment, add_to_collection,
                         add_to_watchlist, add_to_history, remove_from_history,
                         remove_from_collection, remove_from_watchlist, search,
                         checkin_media, delete_checkin)
-from trakt.utils import slugify, extract_ids, airs_date
+from trakt.utils import slugify, airs_date
 from trakt.people import Person
 
 __author__ = 'Jon Nappi'
@@ -197,15 +198,15 @@ def anticipated_shows(page=1, limit=10, extended=None):
     yield [TVShow(**show['show']) for show in data]
 
 
-class TVShow:
+class TVShow(IdsMixin):
     """A Class representing a TV Show object."""
 
     def __init__(self, title='', slug=None, **kwargs):
         super().__init__()
         self.media_type = 'shows'
-        self.top_watchers = self.top_episodes = self.year = self.tvdb = None
-        self.imdb = self.genres = self.certification = self.network = None
-        self.trakt = self.tmdb = self._aliases = self._comments = None
+        self.top_watchers = self.top_episodes = self.year = None
+        self.genres = self.certification = self.network = None
+        self._aliases = self._comments = None
         self._images = self._people = self._ratings = self._translations = None
         self._seasons = None
         self._last_episode = self._next_episode = None
@@ -219,6 +220,9 @@ class TVShow:
 
     @property
     def slug(self):
+        if self._ids.get('slug', None) is not None:
+            return self._ids['slug']
+
         if self._slug is not None:
             return self._slug
 
@@ -244,7 +248,6 @@ class TVShow:
         self._build(data)
 
     def _build(self, data):
-        extract_ids(data)
         for key, val in data.items():
             if hasattr(self, '_' + key):
                 setattr(self, '_' + key, val)
@@ -363,16 +366,6 @@ class TVShow:
         """All of the crew members that worked on this :class:`TVShow`"""
         return [p for p in self.people if getattr(p, 'job')]
 
-    @property
-    def ids(self):
-        """Accessor to the trakt, imdb, and tmdb ids, as well as the trakt.tv
-        slug
-        """
-        return {'ids': {
-            'trakt': self.trakt, 'slug': self.slug, 'imdb': self.imdb,
-            'tmdb': self.tmdb, 'tvdb': self.tvdb
-        }}
-
     @property
     @get
     def images(self):
@@ -434,8 +427,6 @@ class TVShow:
             data = yield self.ext + '/seasons?extended=episodes'
             self._seasons = []
             for season in data:
-                extract_ids(season)
-
                 # Prepare episodes
                 episodes = []
                 for ep in season.pop('episodes', []):
@@ -447,6 +438,7 @@ class TVShow:
                 number = season.pop('number')
                 season = TVSeason(self.title, number, self.slug, **season)
                 self._seasons.append(season)
+
         yield self._seasons
 
     @property
@@ -562,7 +554,7 @@ class TVShow:
     __repr__ = __str__
 
 
-class TVSeason:
+class TVSeason(IdsMixin):
     """Container for TV Seasons"""
 
     def __init__(self, show, season=1, slug=None, **kwargs):
@@ -702,7 +694,7 @@ class TVSeason:
     __repr__ = __str__
 
 
-class TVEpisode:
+class TVEpisode(IdsMixin):
     """Container for TV Episodes"""
 
     def __init__(self, show, season, number=-1, **kwargs):
@@ -713,14 +705,14 @@ class TVEpisode:
         self.number = number
         self.overview = self.title = self.year = self.number_abs = None
         self.first_aired = self.last_updated = None
-        self.trakt = self.tmdb = self.tvdb = self.imdb = None
-        self.tvrage = self._stats = self._images = self._comments = None
+        self.runtime = None
+        self._stats = self._images = self._comments = None
         self._translations = self._ratings = None
         if len(kwargs) > 0:
             self._build(kwargs)
         else:
             self._get()
-        self.episode = self.number  # Backwards compatability
+        self.episode = self.number  # Backwards compatibility
 
     @get
     def _get(self):
@@ -732,7 +724,6 @@ class TVEpisode:
 
     def _build(self, data):
         """Build this :class:`TVEpisode` object with the data in *data*"""
-        extract_ids(data)
         for key, val in data.items():
             if hasattr(self, '_' + key):
                 setattr(self, '_' + key, val)
@@ -782,15 +773,6 @@ class TVEpisode:
         """
         return search(title, search_type='episode', year=year)
 
-    @property
-    def ids(self):
-        """Accessor to the trakt, imdb, and tmdb ids, as well as the trakt.tv
-        slug
-        """
-        return {'ids': {
-            'trakt': self.trakt, 'imdb': self.imdb, 'tmdb': self.tmdb
-        }}
-
     @property
     @get
     def images(self):
